pub(crate) fn decode_header(bytes: &[u8]) -> Result<Header>Expand description
Decodes and verifies the header from the first HEADER_LEN bytes of an
object.
pub(crate) fn decode_header(bytes: &[u8]) -> Result<Header>Decodes and verifies the header from the first HEADER_LEN bytes of an
object.