fn object_crc32(bytes_before_trailer: &[u8], trailer: FixedTrailer) -> u32Expand description
Checksum of everything but the object checksum itself, so the trailer can carry it.
fn object_crc32(bytes_before_trailer: &[u8], trailer: FixedTrailer) -> u32Checksum of everything but the object checksum itself, so the trailer can carry it.